@@ -35,6 +35,7 @@ from .compilers import (
     is_library,
     is_llvm_ir,
     is_object,
+    is_separate_compile,
     is_source,
 )
 
@@ -214,8 +215,6 @@ def get_llvm_tool_names(tool: str) -> T.List[str]:
     # unless it becomes a stable release.
     suffixes = [
         '', # base (no suffix)
-        '-21.1', '21.1',
-        '-21',  '21',
         '-20.1', '20.1',
         '-20',  '20',
         '-19.1', '19.1',
@@ -939,6 +938,9 @@ class Environment:
     def is_assembly(self, fname: 'mesonlib.FileOrString') -> bool:
         return is_assembly(fname)
 
+    def is_separate_compile(self, fname: 'mesonlib.FileOrString') -> bool:
+        return is_separate_compile(fname)
+
     def is_llvm_ir(self, fname: 'mesonlib.FileOrString') -> bool:
         return is_llvm_ir(fname)
 
