@@ -6,3 +6,6 @@ if __name__ == "__main__":
     dep1 = MesonDep1.Dep1.new()
     dep2 = MesonDep2.Dep2.new("Hello, meson/py!")
     s.print_message(dep1, dep2)
+
+    s2 = Meson.Sample2.new()
+    s2.print_message()
