@@ -1,7 +1,7 @@
 #include "stdio.h"
 #include "zlib.h"
 
-int main() {
+int main(void) {
     printf("%s\n", zlibVersion());
     return 0;
 }
