@@ -1261,9 +1261,8 @@ class LinuxlikeTests(BasePlatformTests):
         myenv['PKG_CONFIG_PATH'] = _prepend_pkg_config_path(self.privatedir)
         stdo = subprocess.check_output([PKG_CONFIG, '--libs-only-l', 'libsomething'], env=myenv)
         deps = [b'-lgobject-2.0', b'-lgio-2.0', b'-lglib-2.0', b'-lsomething']
-        if is_windows() or is_osx() or is_openbsd():
+        if is_windows() or is_cygwin() or is_osx() or is_openbsd():
             # On Windows, libintl is a separate library
-            # It used to be on Cygwin as well, but no longer is.
             deps.append(b'-lintl')
         self.assertEqual(set(deps), set(stdo.split()))
 
@@ -1894,7 +1893,7 @@ class LinuxlikeTests(BasePlatformTests):
         self.assertIn('build t13-e1: c_LINKER t13-e1.p/main.c.o | libt12-s1.a libt13-s3.a\n', content)
 
     def test_top_options_in_sp(self):
-        testdir = os.path.join(self.unit_test_dir, '125 pkgsubproj')
+        testdir = os.path.join(self.unit_test_dir, '126 pkgsubproj')
         self.init(testdir)
 
     def test_unreadable_dir_in_declare_dep(self):
@@ -1973,7 +1972,7 @@ class LinuxlikeTests(BasePlatformTests):
             self.check_has_flag(compdb, sub2src, '-O2')
 
     def test_sanitizers(self):
-        testdir = os.path.join(self.unit_test_dir, '127 sanitizers')
+        testdir = os.path.join(self.unit_test_dir, '128 sanitizers')
 
         with self.subTest('no b_sanitize value'):
             try:
